@@ -370,6 +370,12 @@ IconMgr *iconp;
 	LookInList(Scr->AutoRaise, tmp_win->full_name,
 			      &tmp_win->class);
     if (tmp_win->auto_raise) Scr->NumAutoRaises++;
+
+    tmp_win->auto_lower = Scr->AutoLowerDefault ||
+	LookInList(Scr->AutoLower, tmp_win->full_name,
+			      &tmp_win->class);
+    if (tmp_win->auto_lower) Scr->NumAutoLowers++;
+
     tmp_win->iconify_by_unmapping = Scr->IconifyByUnmapping;
     if (Scr->IconifyByUnmapping)
     {
@@ -409,7 +415,8 @@ IconMgr *iconp;
 	}
 	if (t) tmp_win->UnmapByMovingFarAway = t->UnmapByMovingFarAway;
     }
-    if (Scr->WindowRingAll ||
+    if ((Scr->WindowRingAll &&
+	!LookInList(Scr->WindowRingExcludeL, tmp_win->full_name, &tmp_win->class)) ||
 	LookInList(Scr->WindowRingL, tmp_win->full_name, &tmp_win->class)) {
 	if (Scr->Ring) {
 	    tmp_win->ring.next = Scr->Ring->ring.next;
