@@ -348,7 +348,7 @@ int ParseTwmrc (filename)
 	status = doparse (m4twmFileInput, "file", cp);
 	wait (0);
 	fclose (twmrc);
-        fclose (raw);
+        if (GoThroughM4) fclose (raw);
 #else
 	status = doparse (twmFileInput, "file", cp);
 	fclose (twmrc);
@@ -696,6 +696,7 @@ static TwmKeyword keytable[] = {
     { "alwaysshowwindowwhenmovingfromworkspacemanager", KEYWORD, kw0_ShowWinWhenMovingInWmgr },
     { "animationspeed",		NKEYWORD, kwn_AnimationSpeed },
     { "autofocustotransients",  KEYWORD, kw0_AutoFocusToTransients }, /* kai */
+    { "autolower",		AUTO_LOWER, 0 },
     { "autooccupy",		KEYWORD, kw0_AutoOccupy },
     { "autoraise",		AUTO_RAISE, 0 },
     { "autoraiseicons",		KEYWORD, kw0_AutoRaiseIcons },
@@ -740,6 +741,7 @@ static TwmKeyword keytable[] = {
     { "f.adoptwindow",		FKEYWORD, F_ADOPTWINDOW },
     { "f.altcontext",		FKEYWORD, F_ALTCONTEXT },
     { "f.altkeymap",		FSKEYWORD, F_ALTKEYMAP },
+    { "f.autolower",		FKEYWORD, F_AUTOLOWER },
     { "f.autoraise",		FKEYWORD, F_AUTORAISE },
     { "f.backiconmgr",		FKEYWORD, F_BACKICONMGR },
     { "f.backmapiconmgr",	FKEYWORD, F_BACKMAPICONMGR },
@@ -776,6 +778,11 @@ static TwmKeyword keytable[] = {
     { "f.hzoom",		FKEYWORD, F_HORIZOOM },
     { "f.iconify",		FKEYWORD, F_ICONIFY },
     { "f.identify",		FKEYWORD, F_IDENTIFY },
+    { "f.initsize",		FKEYWORD, F_INITSIZE },
+    { "f.jumpdown",		FSKEYWORD, F_JUMPDOWN },
+    { "f.jumpleft",		FSKEYWORD, F_JUMPLEFT },
+    { "f.jumpright",		FSKEYWORD, F_JUMPRIGHT },
+    { "f.jumpup",		FSKEYWORD, F_JUMPUP },
     { "f.lefticonmgr",		FKEYWORD, F_LEFTICONMGR },
     { "f.leftworkspace",	FKEYWORD, F_LEFTWORKSPACE },
     { "f.leftzoom",		FKEYWORD, F_LEFTZOOM },
@@ -785,6 +792,7 @@ static TwmKeyword keytable[] = {
     { "f.movemenu",		FKEYWORD, F_MOVEMENU },
     { "f.movepack",		FKEYWORD, F_MOVEPACK },
     { "f.movepush",		FKEYWORD, F_MOVEPUSH },
+    { "f.moveresize",		FSKEYWORD, F_MOVERESIZE },
     { "f.nexticonmgr",		FKEYWORD, F_NEXTICONMGR },
     { "f.nextworkspace",	FKEYWORD, F_NEXTWORKSPACE },
     { "f.nop",			FKEYWORD, F_NOP },
@@ -809,6 +817,7 @@ static TwmKeyword keytable[] = {
     { "f.righticonmgr",		FKEYWORD, F_RIGHTICONMGR },
     { "f.rightworkspace",	FKEYWORD, F_RIGHTWORKSPACE },
     { "f.rightzoom",		FKEYWORD, F_RIGHTZOOM },
+    { "f.ring",			FKEYWORD, F_RING },
     { "f.savegeometry",		FKEYWORD, F_SAVEGEOMETRY },
     { "f.saveyourself",		FKEYWORD, F_SAVEYOURSELF },
     { "f.separator",		FKEYWORD, F_SEPARATOR },
@@ -1008,6 +1017,7 @@ static TwmKeyword keytable[] = {
     { "windowfunction",		WINDOW_FUNCTION, 0 },
     { "windowregion",		WINDOW_REGION, 0 },
     { "windowring",		WINDOW_RING, 0 },
+    { "windowringexclude",      WINDOW_RING_EXCLUDE, 0},
     { "wmgrbuttonshadowdepth",	NKEYWORD, kwn_WMgrButtonShadowDepth },
     { "wmgrbuttonstyle",	SKEYWORD, kws_WMgrButtonStyle },
     { "wmgrhorizbuttonindent",	NKEYWORD, kwn_WMgrHorizButtonIndent },
